DeviceDetailsPlugin class
Constructors
- DeviceDetailsPlugin({String? appName, String? packageName, String? version, String? buildNumber, String? flutterAppVersion, String? osVersion, String? totalInternalStorage, String? freeInternalStorage, String? networkOperator, String? totalRAMSize, String? freeRAMSize, String? screenSizeInInches, String? manufacturer, String? deviceId, String? currentDateTime})
Properties
- appName → String?
-
The app name.
CFBundleDisplayNameon iOS,application/labelon Android.final - buildNumber → String?
-
The build number.
CFBundleVersionon iOS,versionCodeon Android.final - currentDateTime → String?
-
final
- deviceId → String?
-
final
- flutterAppVersion → String?
-
final
- freeInternalStorage → String?
-
final
- freeRAMSize → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- manufacturer → String?
-
final
- networkOperator → String?
-
final
- osVersion → String?
-
final
- packageName → String?
-
The package name.
bundleIdentifieron iOS,getPackageNameon Android.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenSizeInInches → String?
-
final
- totalInternalStorage → String?
-
final
- totalRAMSize → String?
-
final
- version → String?
-
The package version.
CFBundleShortVersionStringon iOS,versionNameon Android.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited